PasswordRequiredCallback typedef

PasswordRequiredCallback = void Function(PDFPasswordFailure failure)

Signature for the callback that is invoked when an encrypted document could not be opened, reporting why in failure.

Implementation

typedef PasswordRequiredCallback = void Function(PDFPasswordFailure failure);